"""Module that holds the parsing functionality."""
from itertools import product

from pydantic_core._pydantic_core import ValidationError

from janus.exceptions.exceptions import ParseJSONError
from janus.models.multiqc.models import (
    PicardInsertSize,
    SamtoolsStats,
    PicardHsMetrics,
    PicardAlignmentSummary,
    SomalierIndividual,
    SomalierComparison,
    PeddyCheck,
    PicardRNASeqMetrics,
    STARAlignment,
)

models: list = [
    PicardInsertSize,
    SamtoolsStats,
    PicardHsMetrics,
    PicardAlignmentSummary,
    SomalierIndividual,
    SomalierComparison,
    PeddyCheck,
    PicardRNASeqMetrics,
    STARAlignment,
]


def parse_json(content: list | dict):
    """
    Parse the json content into multiqc models.
         Raises: ParseJSONError in case the content cannot be parsed into a model.
    """
    parsed_content = []
    for entry, model in product(content, models):
        entry_content = content[entry]
        try:
            parsed_content.append(model.model_validate(entry_content))
        except ValidationError:
            pass
    if not parsed_content:
        raise ParseJSONError(f"Failed to parse JSON file.")
    return parsed_content



import logging

from fastapi import FastAPI

from janus.server.api import collect_qc_router

app = FastAPI()

LOG = logging.getLogger("__name__")


@app.get("/")
async def root():
    return {"message": "Welcome to Janus"}


app.include_router(collect_qc_router, prefix="/server", tags=["collect_qc"])



from fastapi import APIRouter, Body
from fastapi.responses import JSONResponse

from janus.dto.collect_qc_request import CreateCollectQCRequest
from janus.dto.collect_qc_response import CollectQCResponse

collect_qc_router = APIRouter()


@collect_qc_router.get(
    "/collect_qc/",
    response_description="Collect qc metrics for a case.",
    response_model=CollectQCResponse,
)
def collect_qc(collect_request: CreateCollectQCRequest = Body(...)) -> JSONResponse:
    """Create a case document in the database."""
    pass
